<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sk">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../forms/aboutdialog.ui" line="14"/>
        <source>About Qmmp</source>
        <translation>O Qmmp</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="49"/>
        <source>About</source>
        <translation>O progarme</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="63"/>
        <source>Authors</source>
        <translation>Autori</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="91"/>
        <source>Thanks To</source>
        <translation>Poďakovanie</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="105"/>
        <source>License Agreement</source>
        <translation>Licencia</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="63"/>
        <source>Qt-based Multimedia Player (Qmmp)</source>
        <translation>Qt-based Multimedia Player (Qmmp)</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="67"/>
        <source>Version: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="68"/>
        <source>Using Qt %1 (compiled with Qt %2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="71"/>
        <source>(c) %1-%2 Qmmp Development Team</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="76"/>
        <source>Input plugins:</source>
        <translation>Vstupné moduly:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="85"/>
        <source>Output plugins:</source>
        <translation>Výstupné moduly:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="94"/>
        <source>Visual plugins:</source>
        <translation>Vizualizačné moduly:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="103"/>
        <source>Effect plugins:</source>
        <translation>Moduly efektov:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="112"/>
        <source>General plugins:</source>
        <translation>Všebecné moduly:</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="77"/>
        <source>Translators</source>
        <translation>Prekladatelia</translation>
    </message>
</context>
<context>
    <name>AddUrlDialog</name>
    <message>
        <location filename="../forms/addurldialog.ui" line="14"/>
        <source>Enter URL to add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/addurldialog.ui" line="43"/>
        <source>&amp;Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/addurldialog.ui" line="50"/>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../addurldialog.cpp" line="124"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../forms/configdialog.ui" line="314"/>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="319"/>
        <source>Filename</source>
        <translation>Názov súboru</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="286"/>
        <source>Artist</source>
        <translation>Interprét</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="68"/>
        <location filename="../configdialog.cpp" line="287"/>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="67"/>
        <source>Track</source>
        <translation>Skladba</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="69"/>
        <source>Disabled</source>
        <translation>Zakázané</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="174"/>
        <source>Transports</source>
        <translation>Protokoly</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="184"/>
        <source>Decoders</source>
        <translation>Dekodéry</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="194"/>
        <source>Engines</source>
        <translation>Prehrávače</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="234"/>
        <source>Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="244"/>
        <source>File Dialogs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="254"/>
        <source>User Interfaces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="288"/>
        <source>Title</source>
        <translation>Názov</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="289"/>
        <source>Track number</source>
        <translation>Číslo skladby</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="290"/>
        <source>Two-digit track number</source>
        <translation>Dvojmiestne číslo skladby</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="294"/>
        <source>Disc number</source>
        <translation>Číslo disku</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="298"/>
        <source>Condition</source>
        <translation>Stav</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="308"/>
        <source>&lt;Autodetect&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="309"/>
        <source>Brazilian Portuguese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="310"/>
        <source>Chinese Simplified</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="311"/>
        <source>Chinese Traditional</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="312"/>
        <source>Czech</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="313"/>
        <source>Dutch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="314"/>
        <source>English</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="315"/>
        <source>French</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="316"/>
        <source>German</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="317"/>
        <source>Hebrew</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="318"/>
        <source>Hungarian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="319"/>
        <source>Italian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="320"/>
        <source>Japanese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="321"/>
        <source>Kazakh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="322"/>
        <source>Lithuanian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="323"/>
        <source>Polish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="324"/>
        <source>Russian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="325"/>
        <source>Slovak</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="326"/>
        <source>Spanish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="327"/>
        <source>Turkish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="328"/>
        <source>Ukrainian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="293"/>
        <source>Composer</source>
        <translation>Skladateľ</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="295"/>
        <source>File name</source>
        <translation>Názov súboru</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="296"/>
        <source>File path</source>
        <translation>Cesta k súboru</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="291"/>
        <source>Genre</source>
        <translation>Žáner</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="297"/>
        <source>Year</source>
        <translation>Rok</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="292"/>
        <source>Comment</source>
        <translation>Poznámka</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="14"/>
        <source>Qmmp Settings</source>
        <translation>Qmmp nastavenia</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="58"/>
        <source>Playlist</source>
        <translation>Playlist</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="67"/>
        <source>Plugins</source>
        <translation>Moduly</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="76"/>
        <source>Advanced</source>
        <translation>Pokročilé</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="627"/>
        <source>Replay Gain</source>
        <translation>Zisk pri prehrávaní</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="166"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="123"/>
        <source>Metadata</source>
        <translation>Metadáta</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="135"/>
        <source>Load metadata from files</source>
        <translation>Čítať metadáta zo súborov</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="156"/>
        <source>Title format:</source>
        <translation>Formát titulku:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="259"/>
        <source>Preferences</source>
        <translation>Nastavenia</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="272"/>
        <source>Information</source>
        <translation>Informácie</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="410"/>
        <source>Cover Image Retrieve</source>
        <translation>Získať obrázok obalu</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="416"/>
        <source>Use separate image files</source>
        <translation>Používať samostatné súbory obrázkov</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="426"/>
        <source>Include files:</source>
        <translation>Zahrnúť súbory:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="192"/>
        <location filename="../forms/configdialog.ui" line="436"/>
        <source>Exclude files:</source>
        <translation>Vynechať súbory:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="448"/>
        <source>Recursive search depth:</source>
        <translation>Hĺbka rekurzívneho hľadania:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="373"/>
        <source>Playback</source>
        <translation>Prehrávanie</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="379"/>
        <source>Continue playback on startup</source>
        <translation>Pri štarte pokračovať v prehrávaní</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="386"/>
        <source>Determine file type by content</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="176"/>
        <source>Directory Scanning Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="182"/>
        <source>Restrict files to:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="205"/>
        <source>Miscellaneous</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="211"/>
        <source>Auto-save playlist when modified</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="331"/>
        <source>Look and Feel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="337"/>
        <source>Language:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="393"/>
        <source>Add files from command line to this playlist:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="480"/>
        <source>URL Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="486"/>
        <source>Auto-paste URL from clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="633"/>
        <source>Replay Gain mode:</source>
        <translation>Režim úpravy zisku pri prehrávaní:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="650"/>
        <source>Preamp:</source>
        <translation>Predzosilnenie:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="682"/>
        <location filename="../forms/configdialog.ui" line="727"/>
        <source>dB</source>
        <translation>dB</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="695"/>
        <source>Default gain:</source>
        <translation>Východzý zisk:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="747"/>
        <source>Use  peak info to prevent clipping</source>
        <translation>Použiť informáciu o vrchole k zabráneniu orezu</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="763"/>
        <source>Buffer size:</source>
        <translation>Veľkosť bufferu:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="782"/>
        <source>ms</source>
        <translation>ms</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="818"/>
        <source>16-bit output</source>
        <translation>16bitový výstup</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="85"/>
        <source>Connectivity</source>
        <translation>Pripojenie k sieti</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="525"/>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="537"/>
        <source>Enable proxy usage</source>
        <translation>Povoliť používanie proxy</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="544"/>
        <source>Proxy host name:</source>
        <translation>Adresa proxy:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="557"/>
        <source>Proxy port:</source>
        <translation>Port proxy:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="570"/>
        <source>Use authentication with proxy</source>
        <translation>Použiť autentifikáciu s proxy</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="577"/>
        <source>Proxy user name:</source>
        <translation>Proxy použivateľské meno:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="590"/>
        <source>Proxy password:</source>
        <translation>Proxy heslo:</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="214"/>
        <source>Visualization</source>
        <translation>Vizualizácie</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="204"/>
        <source>Effects</source>
        <translation>Efekty</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="224"/>
        <source>General</source>
        <translation>Všeobecné</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="94"/>
        <location filename="../forms/configdialog.ui" line="757"/>
        <source>Audio</source>
        <translation>Zvuk</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="811"/>
        <source>Use software volume control</source>
        <translation>Používať softwarové ovládanie hlasitosti</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="142"/>
        <source>Convert underscores to blanks</source>
        <translation>Previesť podčiarknutia na medzery</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="149"/>
        <source>Convert %20 to blanks</source>
        <translation>Previesť %20 na mdezery</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../forms/detailsdialog.ui" line="14"/>
        <source>Details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/detailsdialog.ui" line="42"/>
        <source>Open the directory containing this file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/detailsdialog.ui" line="45"/>
        <source>...</source>
        <translation type="unfinished">...</translation>
    </message>
    <message>
        <location filename="../forms/detailsdialog.ui" line="59"/>
        <source>Summary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="110"/>
        <source>Title</source>
        <translation type="unfinished">Názov</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="111"/>
        <source>Artist</source>
        <translation type="unfinished">Interprét</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="112"/>
        <source>Album</source>
        <translation type="unfinished">Album</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="113"/>
        <source>Comment</source>
        <translation type="unfinished">Poznámka</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="114"/>
        <source>Genre</source>
        <translation type="unfinished">Žáner</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="115"/>
        <source>Composer</source>
        <translation type="unfinished">Skladateľ</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="117"/>
        <source>Year</source>
        <translation type="unfinished">Rok</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="119"/>
        <source>Track</source>
        <translation type="unfinished">Skladba</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="121"/>
        <source>Disc number</source>
        <translation type="unfinished">Číslo disku</translation>
    </message>
</context>
<context>
    <name>JumpToTrackDialog</name>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="59"/>
        <source>Q</source>
        <translation>Q</translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="60"/>
        <source>J</source>
        <translation>J</translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="61"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="90"/>
        <location filename="../jumptotrackdialog.cpp" line="143"/>
        <source>Unqueue</source>
        <translation>Vyradiť</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="70"/>
        <location filename="../jumptotrackdialog.cpp" line="92"/>
        <location filename="../jumptotrackdialog.cpp" line="145"/>
        <source>Queue</source>
        <translation>Zaradiť</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="14"/>
        <source>Jump To Track</source>
        <translation>Preskočiť na skladbu</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="37"/>
        <source>Filter</source>
        <translation>Filter</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="83"/>
        <source>Refresh</source>
        <translation>Obnoviť</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="96"/>
        <source>Jump To</source>
        <translation>Preskočiť na</translation>
    </message>
</context>
<context>
    <name>PlayListDownloader</name>
    <message>
        <location filename="../playlistdownloader.cpp" line="108"/>
        <source>Unsupported playlist format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PlayListManager</name>
    <message>
        <location filename="../playlistmanager.cpp" line="164"/>
        <location filename="../playlistmanager.cpp" line="352"/>
        <source>Playlist</source>
        <translation type="unfinished">Playlist</translation>
    </message>
</context>
<context>
    <name>QmmpUiSettings</name>
    <message>
        <location filename="../qmmpuisettings.cpp" line="42"/>
        <source>Playlist</source>
        <translation type="unfinished">Playlist</translation>
    </message>
</context>
<context>
    <name>QtFileDialogFactory</name>
    <message>
        <location filename="../qtfiledialog.cpp" line="34"/>
        <source>Qt File Dialog</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TagEditor</name>
    <message>
        <location filename="../forms/tageditor.ui" line="14"/>
        <source>Tag Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="38"/>
        <source>Title:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="64"/>
        <source>Artist:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="90"/>
        <source>Album:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="113"/>
        <source>Composer:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="133"/>
        <source>Genre:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="163"/>
        <source>Track:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="184"/>
        <location filename="../forms/tageditor.ui" line="222"/>
        <location filename="../forms/tageditor.ui" line="254"/>
        <source>?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="197"/>
        <source>Year:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="244"/>
        <source>Disc number:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="269"/>
        <source>Comment:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="305"/>
        <source>Include selected tag in file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TemplateEditor</name>
    <message>
        <location filename="../forms/templateeditor.ui" line="14"/>
        <source>Template Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/templateeditor.ui" line="39"/>
        <source>Reset</source>
        <translation type="unfinished">Zresetovať</translation>
    </message>
    <message>
        <location filename="../forms/templateeditor.ui" line="46"/>
        <source>Insert</source>
        <translation type="unfinished">Vložiť</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="50"/>
        <source>Artist</source>
        <translation type="unfinished">Interprét</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="51"/>
        <source>Album</source>
        <translation type="unfinished">Album</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="52"/>
        <source>Title</source>
        <translation type="unfinished">Názov</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="53"/>
        <source>Track number</source>
        <translation type="unfinished">Číslo skladby</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="54"/>
        <source>Two-digit track number</source>
        <translation type="unfinished">Dvojmiestne číslo skladby</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="55"/>
        <source>Genre</source>
        <translation type="unfinished">Žáner</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="56"/>
        <source>Comment</source>
        <translation type="unfinished">Poznámka</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="57"/>
        <source>Composer</source>
        <translation type="unfinished">Skladateľ</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="58"/>
        <source>Duration</source>
        <translation type="unfinished">Dĺžka</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="59"/>
        <source>Disc number</source>
        <translation type="unfinished">Číslo disku</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="60"/>
        <source>File name</source>
        <translation type="unfinished">Názov súboru</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="61"/>
        <source>File path</source>
        <translation type="unfinished">Cesta k súboru</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="62"/>
        <source>Year</source>
        <translation type="unfinished">Rok</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="63"/>
        <source>Condition</source>
        <translation type="unfinished">Stav</translation>
    </message>
</context>
<context>
    <name>UiHelper</name>
    <message>
        <location filename="../uihelper.cpp" line="134"/>
        <source>All Supported Bitstreams</source>
        <translation type="unfinished">Všetky podporované formáty</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="139"/>
        <source>Select one or more files to open</source>
        <translation type="unfinished">Vyberte jeden alebo viac súborov na otvorenie</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="146"/>
        <source>Choose a directory</source>
        <translation type="unfinished">Vyberte priečinok</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="162"/>
        <location filename="../uihelper.cpp" line="183"/>
        <source>Playlist Files</source>
        <translation type="unfinished">Súbory playlistov</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="164"/>
        <source>Open Playlist</source>
        <translation type="unfinished">Otvoriť playlist</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="184"/>
        <source>Save Playlist</source>
        <translation type="unfinished">Uložiť playlist</translation>
    </message>
</context>
</TS>
